@@ -19,7 +19,13 @@ module Data.HashTable.Internal.CacheLine
   , maskw#
   ) where
 
+#if MIN_VERSION_base(4,4,0)
+import           Control.Monad.ST (ST)
+import           Control.Monad.ST.Unsafe
+#else
 import           Control.Monad.ST
+#endif
+
 import           Data.HashTable.Internal.IntArray (IntArray)
 import qualified Data.HashTable.Internal.IntArray as M
 
@@ -36,6 +42,13 @@ import           GHC.Int
 import           Data.HashTable.Internal.Utils
 import           GHC.Exts
 
+#if __GLASGOW_HASKELL__ >= 707
+import GHC.Exts (isTrue#)
+#else
+isTrue# :: Bool -> Bool
+isTrue# = id
+#endif
+
 
 {-# INLINE prefetchRead  #-}
 {-# INLINE prefetchWrite #-}
@@ -177,7 +190,7 @@ advanceByCacheLineSize !(I# start0#) !(I# vecSize#) = out
 
 {-# INLINE isCacheLineAligned #-}
 isCacheLineAligned :: Int -> Bool
-isCacheLineAligned (I# x#) = r# ==# 0#
+isCacheLineAligned (I# x#) = isTrue# (r# ==# 0#)
   where
     !(I# m#) = cacheLineIntMask
     !mw#     = int2Word# m#
